Release history
===============

.. currentmodule:: tricycle

.. towncrier release notes start

tricycle 0.2.1 (2020-09-30)
---------------------------

* Update to support Trio 0.15.0 and later: rename ``trio.hazmat`` references
  to the new ``trio.lowlevel``.

tricycle 0.2.0 (2019-12-12)
---------------------------

* Add MultiCancelScope, open_service_nursery, ScopedObject, BackgroundObject.

tricycle 0.1.0 (2019-05-06)
---------------------------

* Initial release.
